# Generated by Django 2.1.14 on 2020-09-23 10:49

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0124_auto_20200917_1922'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='ticket',
            name='predecessor_id',
        ),
        migrations.AddField(
            model_name='ticket',
            name='phase_predecessor',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.ProjectPhase'),
        ),
        migrations.AddField(
            model_name='ticket',
            name='ticket_predecessor',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.Ticket'),
        ),
    ]
