# Generated by Django 4.2.11 on 2024-05-23 10:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0179_projectphase_required_date'),
        ('djconnectwise', '0179_ticket_merged_parent_alter_ticket_ticket_predecessor'),
    ]

    operations = [
    ]
