# Generated by Django 4.2.16 on 2024-10-30 15:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0186_configurationstatus_configurationtype_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='member',
            name='title',
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
    ]
