# Generated by Django 4.2.11 on 2024-05-23 12:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0180_alter_companysite_inactive'),
        ('djconnectwise', '0180_merge_20240523_1010'),
    ]

    operations = [
    ]
