# Generated by Django 4.0.10 on 2023-06-16 19:47

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0173_rename_defaultflag_companynotetype_default_flag'),
    ]

    operations = [
        migrations.CreateModel(
            name='CompanyTeamRole',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=50)),
                ('accountManagerFlag', models.BooleanField()),
                ('techFlag', models.BooleanField()),
                ('salesFlag', models.BooleanField()),
            ],
            options={
                'ordering': ('name',),
            },
        ),
        migrations.CreateModel(
            name='CompanyTeam',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('accountManagerFlag', models.BooleanField()),
                ('techFlag', models.BooleanField()),
                ('salesFlag', models.BooleanField()),
                ('company', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djconnectwise.company')),
                ('contact', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djconnectwise.contact')),
                ('location', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djconnectwise.location')),
                ('member', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djconnectwise.member')),
                ('team_role', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djconnectwise.companyteamrole')),
            ],
            options={
                'ordering': ('id',),
            },
        ),
        migrations.CreateModel(
            name='CompanyTeamRoleTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_companyteamrole',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.companyteamrole',),
        ),
        migrations.CreateModel(
            name='CompanyTeamTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_companyteam',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.companyteam',),
        ),
    ]
