# Generated by Django 4.0 on 2022-02-24 16:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0159_alter_ticket_budget_hours'),
    ]

    operations = [
        migrations.AlterField(
            model_name='project',
            name='budget_hours',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=12, null=True),
        ),
    ]
