# Generated by Django 4.2.11 on 2024-06-05 16:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0183_companytype_default_flag_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='ContactType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.CharField(max_length=250)),
                ('default_flag', models.BooleanField()),
                ('service_alert_flag', models.BooleanField(blank=True, null=True)),
                ('service_alert_message', models.TextField(blank=True, null=True)),
            ],
            options={
                'ordering': ('description',),
            },
        ),
        migrations.CreateModel(
            name='ContactTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_contacttype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.contacttype',),
        ),
    ]
