# Generated by Django 4.0.7 on 2023-03-31 10:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0169_connectwiseboard_time_entry_discussion_flag_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='ticket',
            name='predecessor_closed_flag',
            field=models.BooleanField(default=False),
        ),
    ]
