# Generated by Django 4.2.11 on 2024-05-17 15:19

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0178_alter_ticket_work_role_alter_ticket_work_type'),
    ]

    operations = [
        migrations.CreateModel(
            name='CompanySite',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('inactive', models.BooleanField(default=False)),
                ('company', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djconnectwise.company')),
            ],
            options={
                'ordering': ('id',),
            },
        ),
        migrations.CreateModel(
            name='CompanySiteTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_companysite',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.companysite',),
        ),
        migrations.AddField(
            model_name='ticket',
            name='company_site',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.companysite'),
        ),
    ]
