# Generated by Django 4.2.11 on 2024-05-14 20:34

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0178_alter_ticket_work_role_alter_ticket_work_type'),
    ]

    operations = [
        migrations.AddField(
            model_name='ticket',
            name='merged_parent',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='merged_parent_ticket', to='djconnectwise.ticket'),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='ticket_predecessor',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='ticket_predecessor_ticket', to='djconnectwise.ticket'),
        ),
    ]
