# Generated by Django 3.1.7 on 2021-11-05 09:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0157_auto_20211102_1328'),
    ]

    operations = [
        migrations.AlterField(
            model_name='timeentry',
            name='notes',
            field=models.TextField(blank=True, max_length=50000, null=True),
        ),
    ]
