# Generated by Django 4.0.4 on 2022-08-05 17:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0165_sourcetracker'),
    ]

    operations = [
        migrations.RenameField(
            model_name='ticket',
            old_name='initial',
            new_name='initial_description',
        ),
        migrations.AddField(
            model_name='ticket',
            name='is_issue_flag',
            field=models.BooleanField(null=True),
        ),
    ]
