# Generated by Django 4.0.4 on 2022-06-22 07:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0162_source'),
    ]

    operations = [
        migrations.AddField(
            model_name='ticket',
            name='initial',
            field=models.CharField(blank=True, max_length=5000, null=True),
        ),
    ]
