# Generated by Django 4.0.10 on 2023-10-18 11:43

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0176_project_billing_method'),
    ]

    operations = [
        migrations.AddField(
            model_name='ticket',
            name='work_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.workrole'),
        ),
        migrations.AddField(
            model_name='ticket',
            name='work_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.worktype'),
        ),
    ]
