# Generated by Django 3.1.7 on 2021-04-27 22:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0148_auto_20210317_1424'),
    ]

    operations = [
        migrations.AlterField(
            model_name='servicenote',
            name='text',
            field=models.TextField(blank=True, max_length=4000, null=True),
        ),
    ]
