# Generated by Django 4.2.16 on 2025-02-21 10:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0188_projectrole_projectroletracker_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='sla',
            name='calendar',
        ),
        migrations.RemoveField(
            model_name='slapriority',
            name='priority',
        ),
        migrations.RemoveField(
            model_name='slapriority',
            name='sla',
        ),
        migrations.DeleteModel(
            name='SlaPriorityTracker',
        ),
        migrations.DeleteModel(
            name='SlaTracker',
        ),
        migrations.RemoveField(
            model_name='ticket',
            name='date_resolved_utc',
        ),
        migrations.RemoveField(
            model_name='ticket',
            name='date_resplan_utc',
        ),
        migrations.RemoveField(
            model_name='ticket',
            name='date_responded_utc',
        ),
        migrations.RemoveField(
            model_name='ticket',
            name='do_not_escalate_date',
        ),
        migrations.RemoveField(
            model_name='ticket',
            name='minutes_waiting',
        ),
        migrations.RemoveField(
            model_name='ticket',
            name='res_plan_mins',
        ),
        migrations.RemoveField(
            model_name='ticket',
            name='resolve_mins',
        ),
        migrations.RemoveField(
            model_name='ticket',
            name='respond_mins',
        ),
        migrations.RemoveField(
            model_name='ticket',
            name='sla',
        ),
        migrations.DeleteModel(
            name='Sla',
        ),
        migrations.DeleteModel(
            name='SlaPriority',
        ),
    ]
