# Generated by Django 2.1 on 2019-07-22 14:44

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0104_auto_20190722_1232'),
    ]

    operations = [
        migrations.AddField(
            model_name='activity',
            name='status',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.ActivityStatus'),
        ),
        migrations.AddField(
            model_name='activity',
            name='type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.ActivityType'),
        ),
    ]
