# Generated by Django 4.2.16 on 2025-01-31 15:14

from django.db import migrations, models
import django.db.models.deletion
import django_extensions.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0187_member_title'),
    ]

    operations = [
        migrations.CreateModel(
            name='ProjectRole',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('name', models.CharField(max_length=30)),
                ('manager_role_flag', models.BooleanField(default=False)),
                ('default_contact_flag', models.BooleanField(default=False)),
            ],
            options={
                'verbose_name_plural': 'Project role',
                'ordering': ('name',),
            },
        ),
        migrations.CreateModel(
            name='ProjectRoleTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_projectrole',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.projectrole',),
        ),
        migrations.AddField(
            model_name='projectteammember',
            name='project_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.projectrole'),
        ),
    ]
