# Generated by Django 4.2.11 on 2024-05-22 15:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0179_companysite_companysitetracker_ticket_company_site'),
    ]

    operations = [
        migrations.AlterField(
            model_name='companysite',
            name='inactive',
            field=models.BooleanField(blank=True, default=False, null=True),
        ),
    ]
