# Generated by Django 2.0 on 2019-01-25 11:09

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0081_auto_20181220_0917'),
    ]

    operations = [
        migrations.AlterField(
            model_name='opportunity',
            name='priority',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.OpportunityPriority'),
        ),
    ]
