# Generated by Django 2.1 on 2019-07-16 14:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0091_workrole'),
        ('djconnectwise', '0092_remove_ticket_work_type'),
    ]

    operations = [
    ]
