# Generated by Django 3.1.4 on 2021-01-12 14:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0143_contactcommunication_type'),
    ]

    operations = [
        migrations.AlterField(
            model_name='member',
            name='license_class',
            field=models.CharField(blank=True, choices=[('F', 'Full license'), ('A', 'API license'), ('C', 'StreamlineIT license'), ('X', 'Subcontractor license')], db_index=True, max_length=20, null=True),
        ),
    ]
