# Generated by Django 4.2.11 on 2024-06-05 20:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0184_contacttype_contacttypetracker'),
    ]

    operations = [
        migrations.AddField(
            model_name='contact',
            name='type',
            field=models.ManyToManyField(to='djconnectwise.contacttype'),
        ),
    ]
