# Generated by Django 4.2.11 on 2024-06-05 16:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0182_alter_companysite_inactive'),
    ]

    operations = [
        migrations.AddField(
            model_name='companytype',
            name='default_flag',
            field=models.BooleanField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='companytype',
            name='service_alert_flag',
            field=models.BooleanField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='companytype',
            name='service_alert_message',
            field=models.TextField(blank=True, null=True),
        ),
    ]
