# Generated by Django 4.0 on 2022-05-24 13:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0160_alter_project_budget_hours'),
    ]

    operations = [
        migrations.AddField(
            model_name='activity',
            name='members',
            field=models.ManyToManyField(related_name='member_activities', through='djconnectwise.ScheduleEntry', to='djconnectwise.Member'),
        ),
    ]
