# Generated by Django 4.2.11 on 2024-09-09 16:15

from django.db import migrations, models
import django_extensions.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0185_contact_type'),
    ]

    operations = [
        migrations.CreateModel(
            name='ConfigurationStatus',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('description', models.CharField(max_length=255)),
                ('closed_flag', models.BooleanField(default=False)),
                ('default_flag', models.BooleanField(default=False)),
            ],
            options={
                'verbose_name_plural': 'Configuration Statuses',
                'ordering': ['description'],
            },
        ),
        migrations.CreateModel(
            name='ConfigurationType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('name', models.TextField(max_length=250)),
                ('inactive_flag', models.BooleanField(default=False)),
                ('system_flag', models.BooleanField(default=False)),
            ],
            options={
                'verbose_name_plural': 'Configuration Types',
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='ConfigurationStatusTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_configurationstatus',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.configurationstatus',),
        ),
        migrations.CreateModel(
            name='ConfigurationTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_configurationtype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.configurationtype',),
        ),
    ]
