# Generated by Django 4.0.10 on 2023-10-25 09:00

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0177_ticket_work_role_ticket_work_type'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ticket',
            name='work_role',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='work_role_tickets', to='djconnectwise.workrole'),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='work_type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='work_type_tickets', to='djconnectwise.worktype'),
        ),
    ]
